(ert-run-tests-batch-and-exit
 '(not (or
        ;; Tests failing in sbuild but working on bare metal.
        "rg-integration/rg-executable-results-buffer"
        "rg-integration/rg-executable-through-rg-run"
        ;; Tests failing in autopkgtest due to not a git repository anymore.
        "rg-integration-test/project-root"
        "rg-integration/dwim-search"
        "rg-integration/project-search"
        "rg-unit/isearch-project"
        "rg-unit/menu-define-search"
        "rg-unit/menu-transient-insert"
        )))
